@@ -1,13 +1,13 @@
-### This file is part of 'PGRdup' package for R.
+### This file is part of 'augmentedRCBD' package for R.
 
-### Copyright (C) 2015-2021, ICAR-NBPGR.
+### Copyright (C) 2015-2023, ICAR-NBPGR.
 #
-# PGRdup is free software: you can redistribute it and/or modify it
+# augmentedRCBD is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
 #
-# PGRdup is distributed in the hope that it will be useful, but
+# augmentedRCBD is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
@@ -21,7 +21,7 @@ if (getRversion() >= "2.15.1")  {
   utils::globalVariables(
     c(
       "xmax", "xmin", "ymax", "ymin", "Means", "lower", "upper", "Category",
-      "Trait", "Treatment", "sl", "value", "variable"
+      "Trait", "Treatment", "sl", "value", "variable", "anovatable", "out"
     )
   )
 }
